"use client"

import { useState, useEffect } from "react"
import Link from "next/link"
import { motion } from "framer-motion"
import { useTheme } from "next-themes"
import { cn } from "@/lib/utils"
import { Menu, X } from "lucide-react"
import { ThemeToggle } from "@/components/ThemeToggle"
import { Interactives } from "@/components/header/Interactives"

const navItems = [
  { name: "Home", href: "/" },
  { name: "Posts", href: "/posts" },
  { name: "Categories", href: "/categories" },
  { name: "Tags", href: "/tags" },
  { name: "Admin", href: "/admin" },
]

export default function Header() {
  const [mounted, setMounted] = useState(false)
  const { theme } = useTheme()
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false)

  useEffect(() => {
    setMounted(true)
  }, [])

  const isDarkMode = mounted ? theme === "dark" : false

  return (
    <Interactives className="fixed top-4 left-0 right-0 mx-auto w-[95%] max-w-7xl rounded-xl z-50">
      <motion.div
        className={cn(
          "rounded-xl backdrop-blur-md",
          isDarkMode ? "bg-purple-800/40 shadow-[0_0_15px_rgba(147,51,234,0.3)]" : "bg-slate-600/40 shadow-lg",
        )}
      >
        <div className="px-6 py-4 mx-auto">
          <div className="flex items-center justify-between">
            <motion.div whileHover={{ scale: 1.05 }} whileTap={{ scale: 0.95 }} className="text-xl font-bold">
              <Link href="/" className={cn("transition-colors", isDarkMode ? "text-purple-100" : "text-white")}>
                {process.env.NEXT_PUBLIC_MBLOG_NAME || "Blog"}
              </Link>
            </motion.div>

            {/* Desktop nav */}
            <nav className="hidden md:flex items-center space-x-8">
              {navItems.map((item) => (
                <motion.div key={item.name} whileHover={{ scale: 1.1 }} whileTap={{ scale: 0.9 }}>
                  <Link
                    href={item.href}
                    className={cn(
                      "transition-colors",
                      isDarkMode ? "text-purple-200 hover:text-purple-100" : "text-slate-100 hover:text-white",
                    )}
                  >
                    {item.name}
                  </Link>
                </motion.div>
              ))}
              <div className="">
                <ThemeToggle />
              </div>
            </nav>

            {/* Mobile menu btn */}
            <div className="md:hidden flex items-center space-x-4">
              <ThemeToggle />
              <motion.button
                whileTap={{ scale: 0.9 }}
                whileHover={{ scale: 1.05 }}
                className={cn("transition-colors cursor-pointer", isDarkMode ? "text-purple-200" : "text-slate-100")}
                onClick={() => setMobileMenuOpen(!mobileMenuOpen)}
              >
                {mobileMenuOpen ? <X size={24} /> : <Menu size={24} />}
              </motion.button>
            </div>
          </div>

          {/* Mobile nav */}
          {mobileMenuOpen && (
            <motion.div
              initial={{ opacity: 0, height: 0 }}
              animate={{ opacity: 1, height: "auto" }}
              exit={{ opacity: 0, height: 0 }}
              className={cn(
                "md:hidden mt-4 pt-4 pb-2 border-t",
                isDarkMode ? "border-purple-400/50" : "border-slate-200/70",
              )}
            >
              <nav className="flex flex-col space-y-4">
                {navItems.map((item) => (
                  <motion.div key={item.name} whileHover={{ scale: 0.99 }} whileTap={{ scale: 0.95 }}>
                    <Link
                      href={item.href}
                      className={cn(
                        "block transition-colors",
                        isDarkMode ? "text-purple-200 hover:text-purple-100" : "text-slate-100 hover:text-white",
                      )}
                      onClick={() => setMobileMenuOpen(false)}
                    >
                      {item.name}
                    </Link>
                  </motion.div>
                ))}
              </nav>
            </motion.div>
          )}
        </div>
      </motion.div>
    </Interactives>
  )
}
